import Visibility from '@mui/icons-material/Visibility';
import VisibilityOff from '@mui/icons-material/VisibilityOff';
import { Box, Button } from '@mui/material';
import IconButton from '@mui/material/IconButton';
import InputAdornment from '@mui/material/InputAdornment';
import OutlinedInput from '@mui/material/OutlinedInput';
import Form from 'components/common/Form/Form';
import InputForm from 'components/common/Input/InputForm';
import inputFormClasses from 'components/common/Input/InputForm.module.css';
import useAuth from 'hooks/useAuth';
import { useSnackbar } from 'notistack';
import { useEffect, useState } from 'react';
import axios from 'services/axios';
import * as backendUrl from 'services/backendUrl';
import { displaySnackbar } from 'utils/snackbar';

export default function SignInSection({ handleCloseModal }) {
    // FIXME: group states into object
    const [email, setEmail] = useState('');
    const [password, setPassword] = useState('');
    const [showPassword, setShowPassword] = useState(false);
    const { setAuth, persist, setPersist } = useAuth();
    const { enqueueSnackbar, closeSnackbar } = useSnackbar();

    const handleClickShowPassword = () => setShowPassword((show) => !show);

    const handleMouseDownPassword = (event) => {
        event.preventDefault();
    };

    const handleSubmitButton = (event) => {
        event.preventDefault();
        axios
            .post(`${backendUrl.signInUrl}`, {
                email: email,
                password: password
            })
            .then((response) => {
                if (response.status === 200) {
                    const accessToken = response?.data?.access_token;
                    const updateToken = response?.data?.update_token;
                    const role = response?.data?.role;
                    setAuth({ accessToken, updateToken, role });
                    setPersist(true);
                    localStorage.setItem('updateToken', updateToken);
                    handleCloseModal();
                    const message = 'Вы успешно вошли в систему';
                    const key = displaySnackbar(message, 'success');
                }
            })
            .catch((error) => {
                if (error.response) {
                    const message = error.response.data;
                    const key = enqueueSnackbar(message, {
                        variant: 'error',
                        SnackbarProps: {
                            onClick: () => closeSnackbar(key)
                        }
                    });
                } else if (error.request) {
                    const message = 'Произошла ошибка при отправке запроса';
                    const key = enqueueSnackbar(message, {
                        variant: 'error',
                        SnackbarProps: {
                            onClick: () => closeSnackbar(key)
                        }
                    });
                } else {
                    console.log('Error', error.message);
                }
            });
    };

    const togglePersist = () => {
        setPersist((prev) => !prev);
    };

    useEffect(() => {
        setPersist(true);
        localStorage.setItem('persist', persist);
    }, [persist]);

    return (
        <>
            <p className="text-3xl font-normal">Вход</p>
            <Form
                onSubmit={handleSubmitButton}
                className="flex flex-column flex-wrap justify-start items-center gap-3 px-3">
                <InputForm
                    className="text-lg lg:text-2xl bg-[#fefefe] p-2 border-solid border-[#a3a9b2] border-2 rounded-md w-full"
                    type="email"
                    placeholder="Введите email"
                    required
                    onChange={(e) => setEmail(e.target.value)}
                />
                <OutlinedInput
                    className="text-lg lg:text-2xl p-0 bg-[#fefefe] rounded-md w-full"
                    type={showPassword ? 'text' : 'password'}
                    placeholder="Введите пароль"
                    onChange={(e) => setPassword(e.target.value)}
                    required
                    endAdornment={
                        <InputAdornment position="end">
                            <IconButton
                                className={inputFormClasses.eyeIcon}
                                aria-label="toggle password visibility"
                                onClick={handleClickShowPassword}
                                onMouseDown={handleMouseDownPassword}
                                edge="end">
                                {showPassword ? <VisibilityOff /> : <Visibility />}
                            </IconButton>
                        </InputAdornment>
                    }
                />
                <Box mb={3} className="w-full">
                    <Button
                        className="bg-[var(--color-purple)] rounded-lg font-normal text-[var(--color-form-white)] py-2 w-full text-2xl"
                        type="submit">
                        Войти
                    </Button>
                </Box>
            </Form>
        </>
    );
}
