import BlockRoundedIcon from '@mui/icons-material/BlockRounded';
import DoneRoundedIcon from '@mui/icons-material/DoneRounded';
import { DialogContent, IconButton } from '@mui/material';
import { green, red } from '@mui/material/colors';
import InvitationOverview from 'components/apps/invitation/InvitationOverview';
import PreparedDialog from 'components/common/Dialog/PreparedDialog';
import { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { axiosPrivate } from 'services/axios';
import * as backendUrl from 'services/backendUrl';
import { displaySnackbar } from 'utils/snackbar';

export default function InvitationInfoModal({
    clientInvitations,
    setClientInvitations,
    isOpenInvitationModal,
    setIsOpenInvitationModal
}) {
    const navigate = useNavigate();
    const [open, setOpen] = useState(false);
    const defaultTimeoutMsec = 2000;

    const handleOpen = () => setOpen(true);
    const handleClose = () => {
        setIsOpenInvitationModal(false);
        setOpen(false);
    };

    const handleErrorSnackbarClose = (event, reason) => {
        if (reason === 'clickaway') {
            return;
        }
        setErrorSnackbarOpen(false);
    };

    const handleSuccessSnackbarClose = (event, reason) => {
        if (reason === 'clickaway') {
            return;
        }
        setSuccessSnackbarOpen(false);
    };

    useEffect(() => {
        if (isOpenInvitationModal) {
            handleOpen();
        }
    }, [isOpenInvitationModal]);

    const handleClickOnRejectButton = (invitationId) => {
        // TODO
        setClientInvitations(clientInvitations.filter((item) => item !== invitationId));
        axiosPrivate
            .put(`${backendUrl.invitationRejectUrl}/${invitationId}`)
            .then((response) => {
                if (response.status === 204) {
                    const message = 'Запрос на приглашение успешно отклонён';
                    const snackbarKey = displaySnackbar(message, 'success');
                    setTimeout(() => {
                        navigate('/account/clients', { replace: false });
                    }, defaultTimeoutMsec);
                }
            })
            .catch((error) => {
                if (error.response) {
                    const message = error.response.data;
                    const snackbarKey = displaySnackbar(message, 'error');
                } else if (error.request) {
                    const message = 'Произошла ошибка при отправке запроса';
                    const snackbarKey = displaySnackbar(message, 'error');
                } else {
                    console.log('Error', error.message);
                }
            });
    };

    const handleClickOnAcceptButton = (event, invitationId) => {
        // TODO
        setClientInvitations(clientInvitations.filter((item) => item !== invitationId));
        axiosPrivate
            .put(`${backendUrl.invitationAcceptUrl}/${invitationId}`)
            .then((response) => {
                if (response.status === 204) {
                    const message = 'Запрос на приглашение успешно принят';
                    const snackbarKey = displaySnackbar(message, 'success');
                    // FIXME: refactor it
                    setTimeout(() => {
                        navigate('/account/clients', { replace: false });
                    }, defaultTimeoutMsec);
                }
            })
            .catch((error) => {
                if (error.response) {
                    const message = error.response.data;
                    const snackbarKey = displaySnackbar(message, 'error');
                } else if (error.request) {
                    const message = 'Произошла ошибка при отправке запроса';
                    const snackbarKey = displaySnackbar(message, 'error');
                } else {
                    console.log('Error', error.message);
                }
            });
    };

    return (
        <PreparedDialog
            open={open}
            onClose={handleClose}
            scroll="body"
            aria-labelledby="scroll-dialog-title"
            aria-describedby="scroll-dialog-description">
            <DialogContent
                dividers={scroll === 'paper'}
                className="flex justify-center items-center p-0">
                <div className="flex flex-col items-center bg-[#e3f2fc] shadow-md rounded-lg gap-2 py-3 w-full">
                    {/* FIXME: replace by notistack */}
                    <span className="font-bold text-[var(--color-unused-text-gray)] text-3xl text-center px-4">
                        Запросы на присоединение
                    </span>

                    {clientInvitations.length > 0 ? (
                        clientInvitations.map((invitation) => (
                            <div
                                key={invitation.id}
                                className="bg-[var(--color-contrast-blue)] rounded-xl text-3xl lg:text-2xl text-[var(--color-form-white)] py-4 px-2 lg:px-6 mx-2">
                                <InvitationOverview invitation={invitation} />
                                <div className="flex flex-row justify-center bg-[var(--color-background-light)] rounded-xl">
                                    <IconButton
                                        sx={{ color: green[500] }}
                                        size="medium"
                                        onClick={(event) =>
                                            handleClickOnAcceptButton(event, invitation.id)
                                        }>
                                        <DoneRoundedIcon />
                                    </IconButton>
                                    <IconButton
                                        sx={{ color: red[500] }}
                                        size="medium"
                                        onClick={(event) =>
                                            handleClickOnRejectButton(invitation.id)
                                        }>
                                        <BlockRoundedIcon />
                                    </IconButton>
                                </div>
                            </div>
                        ))
                    ) : (
                        <div className="bg-[var(--color-contrast-blue)] rounded-xl text-2xl lg:text-2xl text-center text-[var(--color-form-white)] py-2 px-2 lg:px-4 mx-2">
                            <p>Непросмотренных запросов нет</p>
                        </div>
                    )}
                </div>
            </DialogContent>
        </PreparedDialog>
    );
}
