import Logout from '@mui/icons-material/Logout';
import Settings from '@mui/icons-material/Settings';
import { ListItemIcon } from '@mui/material';
import Avatar from '@mui/material/Avatar';
import Box from '@mui/material/Box';
import Divider from '@mui/material/Divider';
import IconButton from '@mui/material/IconButton';
import Menu from '@mui/material/Menu';
import MenuItem from '@mui/material/MenuItem';
import Tooltip from '@mui/material/Tooltip';
import userLogo from 'assets/images/user-logo.svg';
import useAuth from 'hooks/useAuth';
import useLogout from 'hooks/useLogout';
import React from 'react';
import { useNavigate } from 'react-router-dom';
import * as roles from 'services/roles';
import styled from 'styled-components';
import { displaySnackbar } from 'utils/snackbar';

const UserInfoContainer = styled.div`
    display: flex;
    justify-content: center;
    align-items: center;
`;

const UserNameContainer = styled.div`
    display: flex;
    flex-direction: column;
    justify-content: center;
    align-items: left;
    margin-left: 10px;
`;

const StyledUserName = styled.span`
    font-size: 24px;
    font-weight: 400;
    color: var(--color-form-dark-black);
    margin: 0;
`;

const StyledRole = styled.span`
    font-size: 24px;
    font-weight: 400;
    color: var(--color-border-gray);
`;

export default function UserProfile() {
    const navigate = useNavigate();
    const [anchorEl, setAnchorEl] = React.useState(null);
    const open = Boolean(anchorEl);
    const { auth } = useAuth();
    const logout = useLogout();

    const handleClick = (event) => {
        setAnchorEl(event.currentTarget);
    };

    const handleClose = () => {
        setAnchorEl(null);
    };

    const handleClickOnLogout = () => {
        logout();
        navigate('/', { replace: false });
    };

    // TODO: later
    const handleSnackbarClick = () => {
        const message = 'Данная возможность скоро будет реализована';
        const snackbarKey = displaySnackbar(message, 'info');
    };

    return (
        <>
            {auth?.accessToken ? (
                <UserInfoContainer>
                    <Box sx={{ display: 'flex', alignItems: 'center', textAlign: 'center' }}>
                        <Tooltip title="Профиль">
                            <IconButton
                                onClick={handleClick}
                                size="medium"
                                sx={{ ml: 2 }}
                                aria-controls={open ? 'account-menu' : undefined}
                                aria-haspopup="true"
                                aria-expanded={open ? 'true' : undefined}>
                                <Avatar
                                    src={userLogo}
                                    sx={{ width: '54px', height: '54px' }}></Avatar>
                            </IconButton>
                        </Tooltip>
                    </Box>
                    <Menu
                        anchorEl={anchorEl}
                        id="account-menu"
                        open={open}
                        onClose={handleClose}
                        onClick={handleClose}
                        transformOrigin={{ horizontal: 'right', vertical: 'top' }}
                        anchorOrigin={{ horizontal: 'right', vertical: 'bottom' }}>
                        <MenuItem
                            onClick={() => {
                                handleSnackbarClick();
                            }}>
                            <ListItemIcon>
                                <Settings fontSize="large" />
                            </ListItemIcon>
                            Настройки
                        </MenuItem>
                        <Divider />
                        <MenuItem onClick={() => handleClickOnLogout()}>
                            <ListItemIcon>
                                <Logout fontSize="large" />
                            </ListItemIcon>
                            Выйти
                        </MenuItem>
                    </Menu>
                    <UserNameContainer>
                        <StyledUserName>
                            {auth?.userInfo?.first_name[0]}. {auth?.userInfo?.last_name}
                        </StyledUserName>
                        {/* FIXME */}
                        <StyledRole>{roles.mentorRole.name}</StyledRole>
                    </UserNameContainer>
                </UserInfoContainer>
            ) : (
                <></>
            )}
        </>
    );
}
