import { DialogContent } from '@mui/material';
import PreparedDialog from 'components/common/Dialog/PreparedDialog';
import PropertyHandledValueFlexContainer from 'components/common/PropertyHandledValueFlexContainer';
import PropertyValueFlexContainer from 'components/common/PropertyValueFlexContainer';
import { useEffect, useState } from 'react';

export default function MentorInfoModal({ selectedMentor, setSelectedMentor }) {
    const [open, setOpen] = useState(false);
    const handleOpen = () => setOpen(true);
    const handleClose = () => {
        setOpen(false);
        setSelectedMentor(null);
    };

    useEffect(() => {
        if (selectedMentor) {
            handleOpen();
        }
    }, [selectedMentor]);

    return (
        <>
            {selectedMentor ? (
                <PreparedDialog
                    open={open}
                    onClose={handleClose}
                    scroll="body"
                    aria-labelledby="scroll-dialog-title"
                    aria-describedby="scroll-dialog-description">
                    <DialogContent
                        dividers={scroll === 'paper'}
                        className="flex justify-center items-center p-0">
                        <div className="flex flex-col items-center bg-[#e3f2fc] shadow-md rounded-lg gap-2 py-3 w-full">
                            <span className="font-bold text-[var(--color-unused-text-gray)] text-3xl text-center px-4 text-nowrap">
                                Информация о тренере
                            </span>
                            <div className="text-2xl md:text-lg bg-[var(--color-contrast-blue)] text-[var(--color-form-white)] rounded-xl px-2 py-3 mb-1 mx-2">
                                <div className="flex flex-col justify-center lg:mx-6">
                                    <PropertyValueFlexContainer
                                        property="Имя:"
                                        value={selectedMentor.first_name}
                                    />
                                    <PropertyValueFlexContainer
                                        property="Фамилия:"
                                        value={selectedMentor.last_name}
                                    />
                                    <PropertyValueFlexContainer
                                        property="Дата рождения:"
                                        value={selectedMentor.birthday}
                                    />
                                    <PropertyHandledValueFlexContainer
                                        property="Пол:"
                                        rawValue={selectedMentor.sex}
                                        targetValue="MALE"
                                        handledValue="мужской"
                                        alternativeHandledValue="женский"
                                    />
                                    <PropertyValueFlexContainer
                                        property="Email:"
                                        value={selectedMentor.email}
                                    />
                                </div>
                            </div>
                        </div>
                    </DialogContent>
                </PreparedDialog>
            ) : (
                <></>
            )}
        </>
    );
}
