import { ExpandMore } from '@mui/icons-material';
import {
    Accordion,
    AccordionDetails,
    AccordionSummary,
    Box,
    Button,
    DialogContent,
    Typography
} from '@mui/material';
import CustomDivider from 'components/common/CustomDivider/CustomDivider';
import PreparedDialog from 'components/common/Dialog/PreparedDialog';
import PropertyValueFlexContainer from 'components/common/PropertyValueFlexContainer';
import { useEffect, useState } from 'react';
import EquipmentDropDownContent from './equipment/EquipmentDropDownContent';
import MediaLinksDropDownContent from './media-link/MediaLinksDropDownContent';
import PropertyDropDownContent from './property-meta-info/PropertyDropDownContent';

export default function ExerciseInfoModal({ selectedExercise, setSelectedExercise }) {
    const [open, setOpen] = useState(false);

    const handleOpen = () => setOpen(true);
    const handleClose = () => {
        setOpen(false);
        setSelectedExercise(null);
    };

    useEffect(() => {
        if (selectedExercise) {
            handleOpen();
        }
    }, [selectedExercise]);

    const handleClickOnDeleteButton = () => {
        // TODO
        console.log('Clicked on delete button');
    };

    // FIXME: check IDs in Accordions
    return (
        <>
            {selectedExercise ? (
                <PreparedDialog
                    open={open}
                    onClose={handleClose}
                    scroll="body"
                    aria-labelledby="scroll-dialog-title"
                    aria-describedby="scroll-dialog-description">
                    <DialogContent
                        dividers={scroll === 'paper'}
                        className="flex justify-center items-center p-0">
                        <div className="flex flex-col items-center bg-[#e3f2fc] shadow-md rounded-lg gap-2 py-3 w-full">
                            <span className="font-bold text-[var(--color-unused-text-gray)] text-3xl text-center px-4">
                                Информация об упражнении
                            </span>
                            <div className="text-2xl md:text-lg bg-[var(--color-contrast-blue)] text-[var(--color-form-white)] rounded-xl px-2 py-3 mb-1 mx-2">
                                <div className="flex flex-col justify-center lg:mx-6">
                                    {selectedExercise ? (
                                        <>
                                            <PropertyValueFlexContainer
                                                property="Название:"
                                                value={selectedExercise.name}
                                            />
                                            <PropertyValueFlexContainer
                                                property="Описание:"
                                                value={selectedExercise.description}
                                            />
                                            <CustomDivider />
                                            <Accordion
                                                sx={{ p: 0 }}
                                                className="text-2xl md:text-lg bg-[var(--color-)] text-[var(--color-form-white)]">
                                                <AccordionSummary
                                                    sx={{ p: 0 }}
                                                    expandIcon={<ExpandMore />}
                                                    aria-controls="panel1-content"
                                                    id="panel1-header">
                                                    <Box px={0}>
                                                        <Typography variant="h5">
                                                            Параметры упражнения
                                                        </Typography>
                                                    </Box>
                                                </AccordionSummary>
                                                <AccordionDetails>
                                                    <PropertyDropDownContent
                                                        metaInfo={
                                                            selectedExercise.parameters_template
                                                        }></PropertyDropDownContent>
                                                </AccordionDetails>
                                            </Accordion>
                                            <Accordion
                                                sx={{ p: 0 }}
                                                className="text-2xl md:text-lg bg-[var(--color-)] text-[var(--color-form-white)]">
                                                <AccordionSummary
                                                    sx={{ p: 0 }}
                                                    expandIcon={<ExpandMore />}
                                                    aria-controls="panel1-content"
                                                    id="panel1-header">
                                                    <Box px={0}>
                                                        <Typography variant="h5">
                                                            Метрики упражнения
                                                        </Typography>
                                                    </Box>
                                                </AccordionSummary>
                                                <AccordionDetails>
                                                    <PropertyDropDownContent
                                                        metaInfo={
                                                            selectedExercise.metrics_template
                                                        }></PropertyDropDownContent>
                                                </AccordionDetails>
                                            </Accordion>
                                            <Accordion
                                                sx={{ p: 0 }}
                                                className="text-2xl md:text-lg bg-[var(--color-)] text-[var(--color-form-white)]">
                                                <AccordionSummary
                                                    sx={{ p: 0 }}
                                                    expandIcon={<ExpandMore />}
                                                    aria-controls="panel1-content"
                                                    id="panel1-header">
                                                    <Box px={0}>
                                                        <Typography variant="h5">
                                                            Необходимое снаряжение
                                                        </Typography>
                                                    </Box>
                                                </AccordionSummary>
                                                <AccordionDetails>
                                                    <EquipmentDropDownContent
                                                        equipments={
                                                            selectedExercise.equipments
                                                        }></EquipmentDropDownContent>
                                                </AccordionDetails>
                                            </Accordion>
                                            <Accordion
                                                sx={{ p: 0 }}
                                                className="text-2xl md:text-lg bg-[var(--color-)] text-[var(--color-form-white)]">
                                                <AccordionSummary
                                                    sx={{ p: 0 }}
                                                    expandIcon={<ExpandMore />}
                                                    aria-controls="panel1-content"
                                                    id="panel1-header">
                                                    <Box px={0}>
                                                        <Typography variant="h5">
                                                            Изображения
                                                        </Typography>
                                                    </Box>
                                                </AccordionSummary>
                                                <AccordionDetails>
                                                    <MediaLinksDropDownContent
                                                        mediaLinks={selectedExercise.media}
                                                    />
                                                </AccordionDetails>
                                            </Accordion>
                                        </>
                                    ) : (
                                        <p>Данные не найдены</p>
                                    )}
                                </div>
                            </div>
                            <Button
                                className="bg-var(--color-delete-for-button) rounded-lg text-2xl font-normal text-var(--color-form-white) p-2"
                                onClick={handleClickOnDeleteButton}>
                                удалить
                            </Button>
                        </div>
                    </DialogContent>
                </PreparedDialog>
            ) : (
                <></>
            )}
        </>
    );
}
