import { ExpandMore } from '@mui/icons-material';
import { Accordion, AccordionDetails, AccordionSummary, Box } from '@mui/material';
import styled from 'styled-components';

const StyledImage = styled.img`
    width: 100%;
    height: auto;
    border-radius: 20px;
    padding: 1vh 0;
`;

export default function EquipmentExtendedInfo({ children, equipment }) {
    return (
        <Accordion>
            <AccordionSummary
                sx={{ p: 0 }}
                expandIcon={<ExpandMore />}
                aria-controls="panel1-content"
                id="panel1-header">
                <Box px={0}>
                    <p className="text-[var(--color-form-dark-black)] text-lg px-2">{children}</p>
                </Box>
            </AccordionSummary>
            <AccordionDetails>
                <>
                    {equipment.properties_template.length > 0 ? (
                        equipment.properties_template.map((meta) => (
                            <div
                                key={meta.name}
                                className="flex flex-row bg-[var(--color-contrast-blue)] rounded-lg py-1 px-2 justify-between items-center">
                                <div className="grid grid-cols-1 gap-1 my-1">
                                    <p className="text-[var(--color-form-white)] text-lg px-2">
                                        {meta.name},
                                    </p>
                                    <p className="text-[var(--color-form-white)] text-lg px-2">
                                        {meta.unit}
                                    </p>
                                    <p className="text-[var(--color-form-white)] text-lg px-2">
                                        [{meta.type}]
                                    </p>
                                </div>
                            </div>
                        ))
                    ) : (
                        <div className="flex flex-row bg-[var(--color-light-gray)] rounded-lg py-1 px-3 justify-between items-center">
                            <span className="text-[var(--color-unused-text-gray)] text-lg py-1">
                                не указано
                            </span>
                        </div>
                    )}
                    {equipment.media.length > 0 ? (
                        equipment.media.map((link) => (
                            // TODO: make request to backend (fetch image by id)
                            <StyledImage key={link.id} src={link.id} alt={link.name} />
                        ))
                    ) : (
                        <div className="flex flex-row bg-[var(--color-light-gray)] rounded-lg py-1 px-3 justify-between items-center">
                            <span className="text-[var(--color-unused-text-gray)] text-lg py-1">
                                не указано
                            </span>
                        </div>
                    )}
                </>
            </AccordionDetails>
        </Accordion>
    );
}
