import { ExpandMore } from '@mui/icons-material';
import {
    Accordion,
    AccordionDetails,
    AccordionSummary,
    Box,
    DialogContent,
    Typography
} from '@mui/material';
import CustomDivider from 'components/common/CustomDivider/CustomDivider';
import PreparedDialog from 'components/common/Dialog/PreparedDialog';
import PropertyValueFlexContainer from 'components/common/PropertyValueFlexContainer';
import ExerciseCard from 'components/pages/exercise/ExerciseCard';
import dayjs from 'dayjs';
import { useEffect, useState } from 'react';

export default function TrainingInfoModal({ selectedTraining, changeSelectedTraining }) {
    const [open, setOpen] = useState(false);
    const handleOpen = () => setOpen(true);
    const handleClose = () => {
        setOpen(false);
        changeSelectedTraining(undefined);
    };

    useEffect(() => {
        if (selectedTraining) {
            handleOpen();
        }
    }, [selectedTraining]);

    return (
        <>
            {console.log(selectedTraining)}
            {selectedTraining ? (
                <PreparedDialog
                    open={open}
                    onClose={handleClose}
                    scroll="body"
                    aria-labelledby="scroll-dialog-title"
                    aria-describedby="scroll-dialog-description">
                    <DialogContent
                        dividers={scroll === 'paper'}
                        className="flex justify-center items-center p-0">
                        <div className="flex flex-col items-center bg-[#e3f2fc] shadow-md rounded-lg gap-2 py-3 w-full">
                            <span className="font-bold text-[var(--color-unused-text-gray)] text-3xl text-center px-4 text-nowrap">
                                Информация о тренировке
                            </span>
                            <div className="text-2xl md:text-lg bg-[var(--color-contrast-blue)] text-[var(--color-form-white)] rounded-xl px-2 py-3 mb-1 mx-2">
                                <div className="flex flex-col justify-center lg:mx-6">
                                    <PropertyValueFlexContainer
                                        property="Заметка:"
                                        value={selectedTraining.note}
                                    />
                                    <PropertyValueFlexContainer
                                        property="Клиент:"
                                        value={
                                            selectedTraining.client.first_name[0] +
                                            '. ' +
                                            selectedTraining.client.last_name
                                        }
                                    />
                                    <PropertyValueFlexContainer
                                        property="Тренер:"
                                        value={
                                            selectedTraining.mentor.first_name[0] +
                                            '. ' +
                                            selectedTraining.mentor.last_name
                                        }
                                    />
                                    <PropertyValueFlexContainer
                                        property="Дата начала:"
                                        value={dayjs(selectedTraining.date_time_start).format(
                                            'DD.MM.YYYY'
                                        )}
                                    />
                                    <PropertyValueFlexContainer
                                        property="Дата окончания (план):"
                                        value={dayjs(selectedTraining.date_plan).format(
                                            'DD.MM.YYYY'
                                        )}
                                    />
                                    <CustomDivider />
                                    <Accordion
                                        sx={{ p: 0 }}
                                        className="text-2xl md:text-lg bg-[var(--color-)] text-[var(--color-form-white)]">
                                        <AccordionSummary
                                            sx={{ p: 0 }}
                                            expandIcon={<ExpandMore />}
                                            aria-controls="panel1-content"
                                            id="panel1-header">
                                            <Box px={0}>
                                                <Typography variant="h5">
                                                    Программа тренировки
                                                </Typography>
                                            </Box>
                                        </AccordionSummary>
                                        <AccordionDetails>
                                            {selectedTraining.exercise_personal.map((exercise) => {
                                                return (
                                                    <div
                                                        key={exercise.id}
                                                        className="bg-white rounded-xl">
                                                        <ExerciseCard exercise={exercise} />
                                                    </div>
                                                );
                                            })}
                                        </AccordionDetails>
                                    </Accordion>
                                </div>
                            </div>
                        </div>
                    </DialogContent>
                </PreparedDialog>
            ) : (
                <></>
            )}
        </>
    );
}
