import { ExpandMore } from '@mui/icons-material';
import HourglassEmptyIcon from '@mui/icons-material/HourglassEmpty';
import { Accordion, AccordionDetails, AccordionSummary, Theme, useMediaQuery } from '@mui/material';
import Typography from '@mui/material/Typography';
import CustomDivider from 'components/common/CustomDivider/CustomDivider';
import dayjs from 'dayjs';
import { useImmer } from 'use-immer';
import ExerciseCard from '../exercise/ExerciseCard';
import PersonalizedExerciseInfoModal from '../exercise/PersonalizedExerciseInfoModal';

const TrainingViewer = ({ selectedTraining }) => {
    const lgDown = useMediaQuery((theme: Theme) => theme.breakpoints.down('lg'));
    const [selectedExercise, setSelectedExercise] = useImmer(undefined);

    return (
        <div className="flex flex-col border-4 border-slate-200 p-2 rounded-md lg:col-span-2 col-span-3">
            <PersonalizedExerciseInfoModal
                selectedExercise={selectedExercise}
                setSelectedExercise={setSelectedExercise}
            />
            {selectedTraining ? (
                <>
                    <div className="px-3">
                        <div className="grid grid-cols-4">
                            <div className="flex flex-row gap-2 col-span-3 items-center">
                                <p className="text-[var(--color-form-dark-black)] px-2 md:text-3xl text-xl">
                                    Тренер:
                                </p>
                                <p className="bg-[var(--color-contrast-blue)] text-[var(--color-form-white)] px-2 rounded-lg md:text-2xl text-xl">
                                    {`${selectedTraining.mentor.first_name} ${selectedTraining.mentor.last_name}`}
                                </p>
                            </div>
                            <div className="flex justify-end items-center col-span-1">
                                {/* TODO: use field to display training status */}
                                {lgDown ? (
                                    <HourglassEmptyIcon className="text-[var(--color-form-dark-black)] border-[var(--color-form-dark-black)] border-2 rounded-lg text-2xl" />
                                ) : (
                                    <p className="bg-[var(--color-unused-text-gray)] text-[var(--color-form-white)] rounded-md px-2 text-xl">
                                        не завершена
                                    </p>
                                )}
                            </div>
                        </div>
                    </div>
                    <CustomDivider />
                    <div className="px-1 md:px-3">
                        <div className="bg-[var(--color-contrast-blue)] w-full p-1 rounded-md flex flex-col gap-1">
                            <p className="text-2xl text-[var(--color-form-white)]">
                                Дата начала:{' '}
                                {dayjs(selectedTraining.date_time_start).format('DD.MM.YYYY')}
                            </p>
                            <p className="text-2xl text-[var(--color-form-white)]">
                                Дата окончания (по плану):{' '}
                                {dayjs(selectedTraining.date_plan).format('DD.MM.YYYY')}
                            </p>
                        </div>
                        <div className="bg-[var(--color-contrast-blue)] w-full p-1 rounded-md mt-1">
                            <p className="text-2xl text-[var(--color-form-white)]">
                                Выполняет:{' '}
                                {`${selectedTraining.client.first_name} ${selectedTraining.client.last_name}`}
                            </p>
                        </div>
                        <div className="bg-[var(--color-contrast-blue)] p-1 w-full rounded-md mt-1">
                            <p className="text-2xl text-[var(--color-form-white)]">
                                Заметка о тренировке:
                            </p>
                            <p className="bg-[var(--color-form-white)] px-2 rounded-md mt-1 break-words text-xl">
                                {selectedTraining.note}
                            </p>
                        </div>
                        <CustomDivider />
                        <Accordion
                            sx={{ p: 0 }}
                            className="text-2xl md:text-lg bg-[var(--color-)] text-[var(--color-form-dark-black)]">
                            <AccordionSummary
                                sx={{ p: 0 }}
                                expandIcon={<ExpandMore />}
                                aria-controls="panel1-content"
                                id="panel1-header">
                                <div className="px-2">
                                    <Typography variant="h5">Программа тренировки</Typography>
                                </div>
                            </AccordionSummary>
                            <AccordionDetails>
                                {selectedTraining.exercise_personal.map((exercise) => {
                                    return (
                                        <div key={exercise.id} className="bg-white rounded-xl mt-2">
                                            <ExerciseCard
                                                exercise={exercise}
                                                onClick={() => setSelectedExercise(exercise)}
                                            />
                                        </div>
                                    );
                                })}
                            </AccordionDetails>
                        </Accordion>
                    </div>
                </>
            ) : (
                <>
                    <div className="px-3 flex justify-center">
                        <Typography color="secondary" variant="h4">
                            Выберите тренировку
                        </Typography>
                    </div>
                </>
            )}
        </div>
    );
};
export default TrainingViewer;
