import { ExpandMore } from '@mui/icons-material';
import {
    Accordion,
    AccordionDetails,
    AccordionSummary,
    Box,
    Button,
    Typography
} from '@mui/material';
import CustomDivider from 'components/common/CustomDivider/CustomDivider';
import useAxiosPrivate from 'hooks/useAxiosPrivate';
import { useEffect } from 'react';
import * as backendUrl from 'services/backendUrl';
import { useImmer } from 'use-immer';
import TrainingCard from './TrainingCard';
import TrainingsCreationModal from './TrainingsCreationModal';

export default function Trainings({ selectedTraining, changeSelectedTraining }) {
    const [clientTrainings, setClientTrainings] = useImmer([]);
    const [mentorTrainings, setMentorTrainings] = useImmer([]);
    const [isCreationModalOpen, setIsCreationModalOpen] = useImmer(false);
    const axiosPrivate = useAxiosPrivate();

    useEffect(() => {
        const getClientTrainings = async () => {
            await axiosPrivate
                .get(`${backendUrl.trainingsUrl}/client`)
                .then((response) => {
                    setClientTrainings(response.data);
                })
                .catch((error) => {
                    console.log(error);
                });
        };
        getClientTrainings();
        const getMentorTrainings = async () => {
            await axiosPrivate
                .get(`${backendUrl.trainingsUrl}/mentor`)
                .then((response) => {
                    setMentorTrainings(response.data);
                })
                .catch((error) => {
                    console.log(error);
                });
        };
        getMentorTrainings();
    }, []);

    return (
        <>
            <TrainingsCreationModal
                isOpenModal={isCreationModalOpen}
                setIsOpenModal={setIsCreationModalOpen}
            />
            {/* FIXME: separate to new big component */}
            <div className="flex flex-col border-4 border-slate-200 p-2 rounded-md lg:col-span-1 col-span-3">
                <Accordion
                    sx={{ p: 0 }}
                    className="text-2xl md:text-lg bg-transparent text-[var(--color-form-white)]">
                    <AccordionSummary
                        sx={{ p: 0 }}
                        expandIcon={<ExpandMore />}
                        aria-controls="panel1-content"
                        id="panel1-header">
                        <Box px={3}>
                            <Typography color="secondary" variant="h4">
                                Тренировки моих клиентов
                            </Typography>
                        </Box>
                    </AccordionSummary>
                    <AccordionDetails>
                        <div>
                            {mentorTrainings.length > 0 ? (
                                <div className="grid grid-cols-1 mb-1">
                                    {mentorTrainings.map((training) => (
                                        <div className="mt-2">
                                            <TrainingCard
                                                training={training}
                                                isSelected={
                                                    selectedTraining
                                                        ? training.id === selectedTraining.id
                                                        : false
                                                }
                                                onClick={() => changeSelectedTraining(training)}
                                                key={training.id}
                                            />
                                        </div>
                                    ))}
                                </div>
                            ) : (
                                <div className="text-2xl md:text-lg text-center bg-[var(--color-contrast-blue)] text-[var(--color-form-white)] rounded-xl px-2 py-3 mb-2">
                                    <p>Тренировки не найдены</p>
                                </div>
                            )}
                        </div>
                        <Button
                            className="bg-[var(--color-thymeleaf)] hover:animate-pulse text-white hover:transition-all hover:duration-200 rounded-xl size-full font-normal hover:shadow-[var(--color-thymeleaf)] hover:shadow-md p-2 mt-1 text-xl"
                            onClick={() => {
                                setIsCreationModalOpen(true);
                            }}>
                            Добавить тренировку
                        </Button>
                    </AccordionDetails>
                </Accordion>
                <CustomDivider />
                <Accordion
                    sx={{ p: 0 }}
                    className="text-2xl md:text-lg bg-transparent text-[var(--color-form-white)]">
                    <AccordionSummary
                        sx={{ p: 0 }}
                        expandIcon={<ExpandMore />}
                        aria-controls="panel1-content"
                        id="panel1-header">
                        <Box px={3}>
                            <Typography color="secondary" variant="h4">
                                Тренировки для меня
                            </Typography>
                        </Box>
                    </AccordionSummary>
                    <AccordionDetails>
                        <div>
                            {clientTrainings.length > 0 ? (
                                <div className="grid grid-cols-1 mb-1">
                                    {clientTrainings.map((training) => (
                                        <div className="grid grid-cols-1 mb-1">
                                            <TrainingCard
                                                training={training}
                                                isSelected={
                                                    selectedTraining
                                                        ? training.id === selectedTraining.id
                                                        : false
                                                }
                                                onClick={() => changeSelectedTraining(training)}
                                                key={training.id}
                                            />
                                        </div>
                                    ))}
                                </div>
                            ) : (
                                <div className="text-2xl md:text-lg text-center bg-[var(--color-contrast-blue)] text-[var(--color-form-white)] rounded-xl px-2 py-3 mb-2">
                                    <p>Тренировки не найдены</p>
                                </div>
                            )}
                        </div>
                    </AccordionDetails>
                </Accordion>
            </div>
        </>
    );
}
