import { ExpandMore } from '@mui/icons-material';
import {
    Accordion,
    AccordionDetails,
    AccordionSummary,
    Box,
    Button,
    FormControl,
    InputLabel,
    MenuItem,
    Select,
    Typography
} from '@mui/material';
import CustomDivider from 'components/common/CustomDivider/CustomDivider';
import Form from 'components/common/Form/Form';
import InputForm from 'components/common/Input/InputForm';
import { useImmer } from 'use-immer';

const ExerciseCreationCard = ({
    exercise,
    availableExercises,
    setFilledExercises,
    setPreparedParameters,
    setPreparedMetrics,
    setPreparedEquipments
}) => {
    const [selectedExerciseTemplate, setSelectedExerciseTemplate] = useImmer(undefined);
    const [personalizedParameters, setPersonalizedParameters] = useImmer([]);
    const [personalizedMetrics, setPersonalizedMetrics] = useImmer([]);
    const [personalizedEquipmentProperties, setPersonalizedEquipmentProperties] = useImmer([]);

    const handleSubmitForm = (event) => {
        event.preventDefault();
        setFilledExercises((prev) => [...prev, selectedExerciseTemplate]);
        setPreparedParameters((prev) => [...prev, personalizedParameters]);
        setPreparedMetrics((prev) => [...prev, personalizedMetrics]);
        setPreparedEquipments((prev) => [...prev, personalizedEquipmentProperties]);
    };

    return (
        <>
            {exercise.id ? (
                <div>
                    <p>{exercise.name}</p>
                </div>
            ) : (
                <div className="bg-[var(--color-form-white)] rounded-lg text-[var(--color-form-dark-black)] text-md">
                    <Accordion
                        sx={{ p: 0 }}
                        className="text-2xl md:text-lg bg-transparent text-[var(--color-form-white)]">
                        <AccordionSummary
                            sx={{ p: 0 }}
                            expandIcon={<ExpandMore />}
                            aria-controls="panel1-content"
                            id="panel1-header">
                            <Box px={3}>
                                <Typography color="secondary" variant="body2">
                                    Персонализировать упражнение
                                </Typography>
                            </Box>
                        </AccordionSummary>
                        <AccordionDetails>
                            <div>
                                <Form>
                                    <FormControl className="w-full">
                                        <InputLabel id="client-select-label">Упражнение</InputLabel>
                                        <Select
                                            labelId="selectedExerciseTemplate-select-component"
                                            id="selectedExerciseTemplate-select-component"
                                            value={selectedExerciseTemplate}
                                            label="Клиент"
                                            onChange={(e) => {
                                                const exercise = e.target.value;
                                                setSelectedExerciseTemplate(exercise);
                                                setPersonalizedParameters(
                                                    exercise.parameters_template
                                                );
                                                setPersonalizedMetrics(exercise.metrics_template);
                                                setPersonalizedEquipmentProperties(
                                                    exercise.equipments
                                                );
                                            }}>
                                            {availableExercises.map((availableExercise) => {
                                                return (
                                                    <MenuItem value={availableExercise}>
                                                        {availableExercise.name}
                                                    </MenuItem>
                                                );
                                            })}
                                        </Select>
                                        {selectedExerciseTemplate &&
                                            selectedExerciseTemplate.parameters_template.map(
                                                (parameter) => {
                                                    return (
                                                        <InputForm
                                                            className="text-lg lg:text-xl bg-[#fefefe] p-2 border-solid border-[#a3a9b2] border-2 rounded-md w-full mt-1 text-[var(--color-form-dark-black)]"
                                                            type="text"
                                                            placeholder={`${parameter.name} (${parameter.unit})`}
                                                            onChange={(e) => {
                                                                // FIXME: check that consider multiple parameters
                                                                setPersonalizedParameters((prev) =>
                                                                    personalizedParameters.filter(
                                                                        (value) =>
                                                                            value.name !==
                                                                            parameter.name
                                                                    ).length > 0
                                                                        ? [
                                                                              ...personalizedParameters.filter(
                                                                                  (value) =>
                                                                                      value.name !==
                                                                                      parameter.name
                                                                              ),
                                                                              {
                                                                                  name: parameter.name,
                                                                                  type: parameter.type,
                                                                                  unit: parameter.unit,
                                                                                  value: e.target
                                                                                      .value
                                                                              }
                                                                          ]
                                                                        : [
                                                                              {
                                                                                  name: parameter.name,
                                                                                  type: parameter.type,
                                                                                  unit: parameter.unit,
                                                                                  value: e.target
                                                                                      .value
                                                                              }
                                                                          ]
                                                                );
                                                            }}
                                                        />
                                                    );
                                                }
                                            )}
                                        {selectedExerciseTemplate &&
                                            selectedExerciseTemplate.metrics_template.map(
                                                (metric) => {
                                                    return (
                                                        <InputForm
                                                            className="text-lg lg:text-xl bg-[#fefefe] p-2 border-solid border-[#a3a9b2] border-2 rounded-md w-full mt-1 text-[var(--color-form-dark-black)]"
                                                            type="text"
                                                            placeholder={`${metric.name} (${metric.unit})`}
                                                            onChange={(e) => {
                                                                // FIXME: check that consider multiple metrics
                                                                setPersonalizedMetrics((prev) =>
                                                                    personalizedMetrics.filter(
                                                                        (value) =>
                                                                            value.name !==
                                                                            metric.name
                                                                    ).length > 0
                                                                        ? [
                                                                              ...personalizedMetrics.filter(
                                                                                  (value) =>
                                                                                      value.name !==
                                                                                      metric.name
                                                                              ),
                                                                              {
                                                                                  name: metric.name,
                                                                                  type: metric.type,
                                                                                  unit: metric.unit,
                                                                                  indicative_value:
                                                                                      e.target
                                                                                          .value,
                                                                                  //   TODO: update at training card at viewer
                                                                                  real_value: null
                                                                              }
                                                                          ]
                                                                        : [
                                                                              {
                                                                                  name: metric.name,
                                                                                  type: metric.type,
                                                                                  unit: metric.unit,
                                                                                  indicative_value:
                                                                                      e.target
                                                                                          .value,
                                                                                  //   TODO: update at training card at viewer
                                                                                  real_value: null
                                                                              }
                                                                          ]
                                                                );
                                                            }}
                                                        />
                                                    );
                                                }
                                            )}
                                        <CustomDivider />
                                        {selectedExerciseTemplate &&
                                            selectedExerciseTemplate.equipments.map(
                                                (equipment, index) => {
                                                    return (
                                                        <>
                                                            <p className="text-lg lg:text-xl w-full mt-1 text-[var(--color-form-dark-black)]">
                                                                {equipment.name}
                                                            </p>
                                                            {equipment.properties_template.map(
                                                                (property) => {
                                                                    return (
                                                                        <>
                                                                            <InputForm
                                                                                className="text-lg lg:text-xl bg-[#fefefe] p-2 border-solid border-[#a3a9b2] border-2 rounded-md w-full mt-1 text-[var(--color-form-dark-black)]"
                                                                                type="text"
                                                                                placeholder={`${property.name} (${property.unit})`}
                                                                                onChange={(e) => {
                                                                                    // TODO: finish later
                                                                                }}
                                                                            />
                                                                            ;
                                                                        </>
                                                                    );
                                                                }
                                                            )}
                                                        </>
                                                    );
                                                }
                                            )}
                                    </FormControl>
                                    <Button
                                        className="bg-[var(--color-thymeleaf)] text-white hover:transition-all hover:duration-200 rounded-xl size-full font-normal hover:shadow-[var(--color-thymeleaf)] hover:shadow-md p-1 mt-1 normal-case text-md"
                                        onClick={handleSubmitForm}>
                                        Подтвердить
                                    </Button>
                                </Form>
                            </div>
                        </AccordionDetails>
                    </Accordion>
                </div>
            )}
        </>
    );
};
export default ExerciseCreationCard;
